<?php

namespace Drupal\assembly\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller for Assembly edit forms.
 *
 * @ingroup assembly
 */
class AssemblyForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form = parent::form($form, $form_state);
    $form['revision_log_message']['#group'] = 'revision_information';
    $form['revision_log_message'] += [
      '#group' => 'revision_information',
      '#states' => [
        'visible' => [
          ':input[name="revision"]' => ['checked' => TRUE],
        ],
      ],
    ];
    $entity = $this->getEntity();
    if (!$entity->isNew()) {
      $form['references'] = _assembly_entity_form_references_field($entity);
      $form['#attached']['library'][] = 'assembly/form';
    }
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $entity = &$this->entity;

    // Save as a new revision if requested to do so.
    if (!$form_state->isValueEmpty('new_revision') && $form_state->getValue('new_revision') != FALSE) {
      $entity->setNewRevision();

      // If a new revision is created, save the current user as revision author.
      $entity->setRevisionCreationTime(\Drupal::time()->getRequestTime());
      $entity->setRevisionUserId(\Drupal::currentUser()->id());
    }
    else {
      $entity->setNewRevision(FALSE);
    }

    $status = parent::save($form, $form_state);

    switch ($status) {
      case SAVED_NEW:
        \Drupal::messenger()->addStatus(t('Created the %label Assembly.', [
          '%label' => $entity->label(),
        ]));
        break;

      default:
      \Drupal::messenger()->addStatus(t('Saved the %label Assembly.', [
          '%label' => $entity->label(),
        ]));
    }

    $form_state->setRedirect('entity.assembly.edit_form', ['assembly' => $entity->id()]);

  }

}
